foo = "bar"

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
